package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BankOrganizationDataDetailSummary;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import net.sourceforge.pinyin4j.PinyinHelper;
import net.sourceforge.pinyin4j.format.HanyuPinyinCaseType;
import net.sourceforge.pinyin4j.format.HanyuPinyinOutputFormat;
import net.sourceforge.pinyin4j.format.HanyuPinyinToneType;
import net.sourceforge.pinyin4j.format.HanyuPinyinVCharType;
import net.sourceforge.pinyin4j.format.exception.BadHanyuPinyinOutputFormatCombination;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BankOrganizationDataDetailImport.class */
public class BankOrganizationDataDetailImport implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BankOrganizationDataDetailImport() {
    }

    public BankOrganizationDataDetailImport(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BankOrganizationDataDetailSummary result = new BankOrganizationDataDetailSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                HSSFRow summaryRow = sheet.getRow(0);
                int rowIndex = 2;
                int columnNum = summaryRow.getPhysicalNumberOfCells();
                HSSFRow recordRowTemp = sheet.getRow(2);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                if (columnNum != 35) {
                    throw new TranFailException("excelError", "模板错误");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw new TranFailException("EBCB0504", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", false);
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String repayStt = "";
        String isGeneral = "";
        boolean amtFlag = true;
        boolean amtFlags = true;
        String publishTime = "";
        String acceptTime = "";
        String openCheckTime = "";
        String checkOperationTime = "";
        String creditOperationTime = "";
        String loanOperationTime = "";
        String repayOperationTime = "";
        String financeAmt = "";
        String financeLimit = "";
        String corName = getCellContent(recordRow, 0, true);
        String orgCode = getCellContent(recordRow, 1, true);
        String financeName = getCellContent(recordRow, 2, true);
        String secendBraUserName = getCellContent(recordRow, 3, true);
        String secendBraUserPhone = getCellContent(recordRow, 4, true);
        String rateBegin = getCellContent(recordRow, 5, false);
        String assureWay = getCellContent(recordRow, 6, true);
        String corContactName = getCellContent(recordRow, 7, true);
        String corContactTel = getCellContent(recordRow, 8, true);
        String incomeLastYear = getCellContent(recordRow, 9, true);
        String salesThisYear = getCellContent(recordRow, 10, true);
        String applyForProduct = getCellContent(recordRow, 11, true);
        String financePurpose = getCellContent(recordRow, 12, true);
        String financeStation = getCellContent(recordRow, 13, true);
        String decomandRemark = getCellContent(recordRow, 14, true);
        String joinProduct = getCellContent(recordRow, 15, true);
        String creditNo = getCellContent(recordRow, 16, true);
        String startDate = getCellContent(recordRow, 17, true);
        String endDate = getCellContent(recordRow, 18, true);
        String assureType = getCellContent(recordRow, 19, true);
        String reGuaOrgCode = getCellContent(recordRow, 20, true);
        String pledgeNo = getCellContent(recordRow, 21, true);
        String patentNo = getCellContent(recordRow, 22, true);
        String creditMoney = getCellContent(recordRow, 23, false);
        String dealUserName = getCellContent(recordRow, 24, true);
        String dealUserPhone = getCellContent(recordRow, 25, true);
        String creditRemark = getCellContent(recordRow, 26, true);
        String loansStartDate = getCellContent(recordRow, 27, true);
        String loansEndDate = getCellContent(recordRow, 28, true);
        String loanContractNum = getCellContent(recordRow, 29, true);
        String lendingRate = getCellContent(recordRow, 30, false);
        String loanAmt = getCellContent(recordRow, 31, false);
        String termOfLoan = getCellContent(recordRow, 32, true);
        String repayAmount = getCellContent(recordRow, 33, false);
        String repayDate = getCellContent(recordRow, 34, true);
        String remark = "";
        String flowStt = "3";
        String opStt = "30";
        String reqStt = "30";
        if ("".equals(corName) || corName == null) {
            remark = String.valueOf(remark) + " 企业名称为空";
        } else {
            String replace = corName.replace("(", "（").replace(")", "）");
            corName = replace;
            if (replace.length() > 50) {
                remark = String.valueOf(remark) + " 企业名称过长";
            }
        }
        if (!"".equals(orgCode) && orgCode != null && !Pattern.compile("^[a-zA-Z0-9[-]]{8,25}").matcher(orgCode).matches()) {
            remark = String.valueOf(remark) + " 统一社会信用代码不符合规则";
        }
        if ("".equals(financeName) || financeName == null) {
            remark = String.valueOf(remark) + " 金融机构为空";
        }
        if ("".equals(secendBraUserName) || secendBraUserName == null) {
            remark = String.valueOf(remark) + " 二级机构联系人姓名为空";
        }
        Pattern tel = Pattern.compile("^((0\\d{2,3}\\-\\d{7,8})|(1[0-9]{10})|(\\d{8}))$");
        if (!"".equals(secendBraUserPhone) && secendBraUserPhone != null && !tel.matcher(secendBraUserPhone).matches()) {
            remark = String.valueOf(remark) + " 二级机构联系人联系方式不符合规则";
        }
        Pattern rate = Pattern.compile("^\\d{1,3}(\\.\\d{1,4})?$");
        if (!"".equals(rateBegin) && rateBegin != null && !rate.matcher(rateBegin).matches()) {
            remark = String.valueOf(remark) + " 期望利率不符合规则";
        }
        if ("".equals(assureWay) || assureWay == null) {
            remark = String.valueOf(remark) + " 担保方式为空";
        }
        if (!"".equals(corContactTel) && corContactTel != null && !tel.matcher(corContactTel).matches()) {
            remark = String.valueOf(remark) + " 联系电话不符合规则";
        }
        Pattern yearReg = Pattern.compile("^[1-9]{1}\\d{0,7}$");
        if (!"".equals(incomeLastYear) && incomeLastYear != null && !yearReg.matcher(incomeLastYear).matches()) {
            remark = String.valueOf(remark) + " 上一年度销售收入不符合规则";
        }
        if (!"".equals(salesThisYear) && salesThisYear != null && !yearReg.matcher(salesThisYear).matches()) {
            remark = String.valueOf(remark) + " 本年度销售收入不符合规则";
        }
        if ("".equals(joinProduct) || joinProduct == null) {
            remark = String.valueOf(remark) + " 对接产品为空";
        }
        Calendar calendar1 = Calendar.getInstance();
        SimpleDateFormat formats = new SimpleDateFormat("yyyy-MM-dd");
        Calendar bef = Calendar.getInstance();
        int befMon = -1;
        int befYear = -1;
        int befDay = -1;
        if ("".equals(startDate) || startDate == null) {
            remark = String.valueOf(remark) + " 授信开始时间为空";
        } else {
            try {
                formats.setLenient(false);
                calendar1.setTime(formats.parse(startDate));
                bef.setTime(formats.parse(startDate));
                befMon = bef.get(2);
                befYear = bef.get(1);
                befDay = bef.get(5);
                creditOperationTime = String.valueOf(formats.format(calendar1.getTime())) + " " + (9 + ((int) (Math.random() * 8.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                calendar1.add(5, -3);
                publishTime = String.valueOf(formats.format(calendar1.getTime())) + " " + (9 + ((int) (Math.random() * 8.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                calendar1.add(5, 1);
                acceptTime = String.valueOf(formats.format(calendar1.getTime())) + " " + (9 + ((int) (Math.random() * 3.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                openCheckTime = String.valueOf(formats.format(calendar1.getTime())) + " " + (12 + ((int) (Math.random() * 3.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                checkOperationTime = String.valueOf(formats.format(calendar1.getTime())) + " " + (15 + ((int) (Math.random() * 2.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused) {
                remark = String.valueOf(remark) + " 授信开始时间格式不正确";
            }
        }
        Calendar aft = Calendar.getInstance();
        int aftMon = -1;
        int aftYear = -1;
        int aftDay = -1;
        if ("".equals(endDate) || endDate == null) {
            remark = String.valueOf(remark) + " 授信结束时间为空";
        } else {
            try {
                formats.setLenient(false);
                aft.setTime(formats.parse(endDate));
                aftMon = aft.get(2);
                aftYear = aft.get(1);
                aftDay = aft.get(5);
            } catch (ParseException unused2) {
                remark = String.valueOf(remark) + " 授信结束时间格式不正确";
            }
        }
        if (aftMon != -1 && befMon != -1 && aftYear != -1 && befYear != -1 && befDay != -1 && aftDay != -1) {
            Double day = Double.valueOf((aftDay - befDay) / 30.0d);
            int month = aftMon - befMon;
            int year = (aftYear - befYear) * 12;
            financeLimit = String.valueOf(Math.abs(month + year + ((int) Math.round(day.doubleValue()))));
        }
        if ("".equals(assureType) || assureType == null) {
            remark = String.valueOf(remark) + " 担保类型为空";
        }
        if ("一般保证".equals(assureType)) {
            isGeneral = "1";
            if ("".equals(reGuaOrgCode) || reGuaOrgCode == null) {
                remark = String.valueOf(remark) + " 担保机构为空";
            }
        }
        if ("质押".equals(assureType)) {
            if ("".equals(pledgeNo) || pledgeNo == null) {
                remark = String.valueOf(remark) + " 担保类型为质押时质押登记号不能为空";
            }
            if ("".equals(patentNo) || patentNo == null) {
                remark = String.valueOf(remark) + " 担保类型为质押时专利号不能为空";
            }
        }
        Pattern reg = Pattern.compile("^\\d{1,5}(\\.\\d{1,6})?$");
        if ("".equals(creditMoney) || creditMoney == null) {
            amtFlag = false;
            remark = String.valueOf(remark) + " 授信金额为空";
        } else if (Double.parseDouble(creditMoney) == 0.0d) {
            amtFlag = false;
            remark = String.valueOf(remark) + " 授信金额不符合规则";
        } else if (!reg.matcher(creditMoney).matches()) {
            amtFlag = false;
            remark = String.valueOf(remark) + " 授信金额不符合规则";
        } else {
            financeAmt = creditMoney;
        }
        if (!"".equals(dealUserPhone) && dealUserPhone != null && !tel.matcher(dealUserPhone).matches()) {
            remark = String.valueOf(remark) + "经办人联系电话不符合规则";
        }
        if (!StringUtils.isBlank(loansStartDate) || !StringUtils.isBlank(loansEndDate) || !StringUtils.isBlank(loanContractNum) || !StringUtils.isBlank(lendingRate) || !StringUtils.isBlank(loanAmt) || !StringUtils.isBlank(termOfLoan)) {
            flowStt = "4";
            opStt = "41";
            reqStt = "40";
            Calendar cal = Calendar.getInstance();
            if ("".equals(loansStartDate) || loansStartDate == null) {
                remark = String.valueOf(remark) + " 贷款起始日为空";
            } else {
                try {
                    formats.setLenient(false);
                    cal.setTime(formats.parse(loansStartDate));
                    loanOperationTime = String.valueOf(formats.format(cal.getTime())) + " " + (9 + ((int) (Math.random() * 8.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                } catch (ParseException unused3) {
                    remark = String.valueOf(remark) + " 贷款起始日格式不正确";
                }
            }
            if ("".equals(loansEndDate) || loansEndDate == null) {
                remark = String.valueOf(remark) + " 贷款到期日为空";
            } else {
                try {
                    formats.setLenient(false);
                    formats.parse(loansEndDate);
                } catch (ParseException unused4) {
                    remark = String.valueOf(remark) + " 贷款到期日格式不正确";
                }
            }
            if (!"".equals(lendingRate) && lendingRate != null && !rate.matcher(lendingRate).matches()) {
                remark = String.valueOf(remark) + " 放款利率不符合规则";
            }
            if ("".equals(loanAmt) || loanAmt == null) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额为空";
            } else if (Double.parseDouble(loanAmt) == 0.0d) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额不符合规则";
            } else if (!reg.matcher(loanAmt).matches()) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额不符合规则";
            }
            if (amtFlag && Double.parseDouble(loanAmt) > Double.parseDouble(creditMoney)) {
                remark = String.valueOf(remark) + " 放款金额不能大于授信金额";
            }
            if ("".equals(termOfLoan) || termOfLoan == null) {
                remark = String.valueOf(remark) + " 放款期限为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d{0,2}$").matcher(termOfLoan).matches()) {
                remark = String.valueOf(remark) + " 放款期限不符合规则";
            }
        }
        if ((!StringUtils.isBlank(repayAmount) || !StringUtils.isBlank(repayDate)) && "40".equals(reqStt)) {
            flowStt = "6";
            opStt = "60";
            reqStt = "60";
            if ("".equals(repayAmount) || repayAmount == null) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额为空";
            } else if (Double.parseDouble(repayAmount) == 0.0d) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额不符合规则";
            } else if (!reg.matcher(repayAmount).matches()) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额不符合规则";
            }
            if (amtFlags) {
                if (Double.parseDouble(repayAmount) > Double.parseDouble(loanAmt)) {
                    remark = String.valueOf(remark) + " 还款金额不能大于放款金额";
                } else if (Double.parseDouble(repayAmount) == Double.parseDouble(loanAmt)) {
                    repayStt = "2";
                } else if (Double.parseDouble(repayAmount) < Double.parseDouble(loanAmt)) {
                    repayStt = "1";
                }
            }
            Calendar repCal = Calendar.getInstance();
            if ("".equals(repayDate) || repayDate == null) {
                remark = String.valueOf(remark) + " 还款时间为空";
            } else {
                try {
                    formats.setLenient(false);
                    repCal.setTime(formats.parse(repayDate));
                    repayOperationTime = String.valueOf(formats.format(repCal.getTime())) + " " + (9 + ((int) (Math.random() * 8.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                } catch (ParseException unused5) {
                    remark = String.valueOf(remark) + " 还款时间格式不正确";
                }
            }
        }
        result.put("corName", corName);
        result.put("orgCode", orgCode);
        result.put("financeName", financeName);
        result.put("secendBraUserName", secendBraUserName);
        result.put("secendBraUserPhone", secendBraUserPhone);
        result.put("publishTime", publishTime);
        result.put("financeAmt", financeAmt);
        result.put("financeLimit", financeLimit);
        result.put("rateBegin", rateBegin);
        result.put("assureWay", assureWay);
        result.put("corContactName", corContactName);
        result.put("corContactTel", corContactTel);
        result.put("incomeLastYear", incomeLastYear);
        result.put("salesThisYear", salesThisYear);
        result.put("applyForProduct", applyForProduct);
        result.put("financePurpose", financePurpose);
        result.put("financeStation", financeStation);
        result.put("decomandRemark", decomandRemark);
        result.put("joinProduct", joinProduct);
        result.put("openCheckTime", openCheckTime);
        result.put("checkOperationTime", checkOperationTime);
        result.put("creditNo", creditNo);
        result.put("startDate", startDate);
        result.put("endDate", endDate);
        result.put("assureType", assureType);
        result.put("pledgeNo", pledgeNo);
        result.put("patentNo", patentNo);
        result.put("creditMoney", creditMoney);
        result.put("dealUserName", dealUserName);
        result.put("dealUserPhone", dealUserPhone);
        result.put("creditRemark", creditRemark);
        result.put("creditOperationTime", creditOperationTime);
        result.put("loansStartDate", loansStartDate);
        result.put("loansEndDate", loansEndDate);
        result.put("loanContractNum", loanContractNum);
        result.put("lendingRate", lendingRate);
        result.put("loanAmt", loanAmt);
        result.put("termOfLoan", termOfLoan);
        result.put("loanOperationTime", loanOperationTime);
        result.put("repayAmount", repayAmount);
        result.put("repayDate", repayDate);
        result.put("repayOperationTime", repayOperationTime);
        result.put("reGuaOrgCode", reGuaOrgCode);
        result.put("repayStt", repayStt);
        result.put("acceptTime", acceptTime);
        result.put("isGeneral", isGeneral);
        result.put("didRemark", remark);
        result.put("flowStt", flowStt);
        result.put("opStt", opStt);
        result.put("reqStt", reqStt);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            cell.setCellType(1);
                            result = cell.getRichStringCellValue().getString();
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v11 */
    /* JADX WARN: Type inference failed for: r0v26 */
    /* JADX WARN: Type inference failed for: r0v7 */
    /* JADX WARN: Type inference failed for: r0v8 */
    /* JADX WARN: Type inference failed for: r0v9, types: [net.sourceforge.pinyin4j.format.exception.BadHanyuPinyinOutputFormatCombination] */
    public String changeToPY(String str) {
        String str2;
        HanyuPinyinOutputFormat hanyuPinyinOutputFormat = new HanyuPinyinOutputFormat();
        hanyuPinyinOutputFormat.setCaseType(HanyuPinyinCaseType.LOWERCASE);
        hanyuPinyinOutputFormat.setToneType(HanyuPinyinToneType.WITHOUT_TONE);
        hanyuPinyinOutputFormat.setVCharType(HanyuPinyinVCharType.WITH_V);
        char[] charArray = str.trim().toCharArray();
        String str3 = "";
        ?? r0 = 0;
        int i = 0;
        while (true) {
            try {
                r0 = i;
                if (r0 >= charArray.length) {
                    break;
                }
                if (Character.toString(charArray[i]).matches("[\\u4E00-\\u9FA5]+")) {
                    str2 = String.valueOf(str3) + PinyinHelper.toHanyuPinyinStringArray(charArray[i], hanyuPinyinOutputFormat)[0];
                    str3 = str2;
                } else {
                    str2 = String.valueOf(str3) + Character.toString(charArray[i]);
                    str3 = str2;
                }
                i++;
                r0 = str2;
            } catch (BadHanyuPinyinOutputFormatCombination e) {
                r0.printStackTrace();
            }
        }
        return str3;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v15, types: [int] */
    /* JADX WARN: Type inference failed for: r0v4 */
    /* JADX WARN: Type inference failed for: r0v8, types: [java.text.ParseException] */
    public static void main(String[] args) {
        Calendar calendar1 = Calendar.getInstance();
        SimpleDateFormat formats = new SimpleDateFormat("yyyy-MM-dd");
        Calendar bef = Calendar.getInstance();
        ?? r0 = 0;
        int befMon = 0;
        try {
            try {
                calendar1.setTime(formats.parse("2020-01-01"));
                System.out.println(String.valueOf(formats.format(calendar1.getTime())) + " " + (9 + ((int) (Math.random() * 3.0d))) + ":" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d)));
                bef.setTime(formats.parse("2020-01-01"));
                r0 = bef.get(2);
                befMon = r0;
                System.out.println(befMon);
                System.out.println(Math.abs(4.5d));
            } catch (ParseException e) {
                r0.printStackTrace();
                System.out.println(0);
                System.out.println(Math.abs(4.5d));
            }
        } catch (Throwable th) {
            System.out.println(befMon);
            System.out.println(Math.abs(4.5d));
            throw th;
        }
    }
}
